#include "gllist.h"
static const float data[]={
	-0.54555,-0.056478,0.836173,-3.67645,-0.551317,0.077574,
	0.00197,-0.021649,0.999764,-3.740631,-0.558176,0.085478,
	0.000763,-0.01871,0.999825,-3.72947,-0.869371,0.096946,
	-0.54555,-0.056478,0.836173,-3.67645,-0.551317,0.077574,
	0.000763,-0.01871,0.999825,-3.72947,-0.869371,0.096946,
	-0.548359,-0.017804,0.836053,-3.699784,-0.759901,0.088664,
	-0.548359,-0.017804,0.836053,-3.699784,-0.759901,0.088664,
	0.000763,-0.01871,0.999825,-3.72947,-0.869371,0.096946,
	-0.530021,0.13773,0.836724,-3.697889,-0.951955,0.098793,
	-0.530021,0.13773,0.836724,-3.697889,-0.951955,0.098793,
	0.000763,-0.01871,0.999825,-3.72947,-0.869371,0.096946,
	-0.004656,-0.025693,0.999659,-3.733767,-1.141917,0.111139,
	-0.530021,0.13773,0.836724,-3.697889,-0.951955,0.098793,
	-0.004656,-0.025693,0.999659,-3.733767,-1.141917,0.111139,
	-0.429713,0.351913,0.831567,-3.666536,-1.140372,0.078261,
	-0.429713,0.351913,0.831567,-3.666536,-1.140372,0.078261,
	-0.004656,-0.025693,0.999659,-3.733767,-1.141917,0.111139,
	-0.020872,-0.032587,0.999251,-3.743747,-1.367219,0.100951,
	-0.429713,0.351913,0.831567,-3.666536,-1.140372,0.078261,
	-0.020872,-0.032587,0.999251,-3.743747,-1.367219,0.100951,
	-0.24021,0.502412,0.830591,-3.639696,-1.242349,0.05719,
	-0.24021,0.502412,0.830591,-3.639696,-1.242349,0.05719,
	-0.020872,-0.032587,0.999251,-3.743747,-1.367219,0.100951,
	-0.091034,0.391629,0.915609,-3.823638,-1.557534,0.081533,
	-0.24021,0.502412,0.830591,-3.639696,-1.242349,0.05719,
	-0.091034,0.391629,0.915609,-3.823638,-1.557534,0.081533,
	0.000909,0.669011,0.743252,-3.581963,-1.413947,-0.104371,
	0.000909,0.669011,0.743252,-3.581963,-1.413947,-0.104371,
	-0.091034,0.391629,0.915609,-3.823638,-1.557534,0.081533,
	-0.041225,-0.030655,0.99868,-3.683069,-1.591975,-0.115233,
	-0.041225,-0.030655,0.99868,-3.683069,-1.591975,-0.115233,
	-0.091034,0.391629,0.915609,-3.823638,-1.557534,0.081533,
	0.231733,0.017467,0.972623,-3.890388,-1.750102,0.017612,
	-0.041225,-0.030655,0.99868,-3.683069,-1.591975,-0.115233,
	0.231733,0.017467,0.972623,-3.890388,-1.750102,0.017612,
	0.002322,-0.058071,0.99831,-3.828485,-1.786559,-0.114095,
	0.00197,-0.021649,0.999764,-3.740631,-0.558176,0.085478,
	0.518386,-0.029316,0.854644,-3.778908,-0.541975,0.064258,
	0.000763,-0.01871,0.999825,-3.72947,-0.869371,0.096946,
	0.518386,-0.029316,0.854644,-3.778908,-0.541975,0.064258,
	0.548941,0.015145,0.835724,-3.805841,-0.798961,0.099237,
	0.000763,-0.01871,0.999825,-3.72947,-0.869371,0.096946,
	0.000763,-0.01871,0.999825,-3.72947,-0.869371,0.096946,
	0.548941,0.015145,0.835724,-3.805841,-0.798961,0.099237,
	-0.004656,-0.025693,0.999659,-3.733767,-1.141917,0.111139,
	0.548941,0.015145,0.835724,-3.805841,-0.798961,0.099237,
	0.549332,-0.018885,0.835391,-3.843256,-0.981402,0.116282,
	-0.004656,-0.025693,0.999659,-3.733767,-1.141917,0.111139,
	0.549332,-0.018885,0.835391,-3.843256,-0.981402,0.116282,
	0.516335,-0.196022,0.833651,-3.884588,-1.261469,0.148322,
	-0.004656,-0.025693,0.999659,-3.733767,-1.141917,0.111139,
	-0.004656,-0.025693,0.999659,-3.733767,-1.141917,0.111139,
	0.516335,-0.196022,0.833651,-3.884588,-1.261469,0.148322,
	-0.020872,-0.032587,0.999251,-3.743747,-1.367219,0.100951,
	0.516335,-0.196022,0.833651,-3.884588,-1.261469,0.148322,
	0.368421,-0.433142,0.82259,-3.914006,-1.486854,0.149147,
	-0.020872,-0.032587,0.999251,-3.743747,-1.367219,0.100951,
	-0.020872,-0.032587,0.999251,-3.743747,-1.367219,0.100951,
	0.368421,-0.433142,0.82259,-3.914006,-1.486854,0.149147,
	-0.091034,0.391629,0.915609,-3.823638,-1.557534,0.081533,
	0.368421,-0.433142,0.82259,-3.914006,-1.486854,0.149147,
	0.255239,-0.528232,0.80983,-4.015306,-1.659952,0.130331,
	-0.091034,0.391629,0.915609,-3.823638,-1.557534,0.081533,
	-0.091034,0.391629,0.915609,-3.823638,-1.557534,0.081533,
	0.255239,-0.528232,0.80983,-4.015306,-1.659952,0.130331,
	0.231733,0.017467,0.972623,-3.890388,-1.750102,0.017612,
	0.255239,-0.528232,0.80983,-4.015306,-1.659952,0.130331,
	0.791625,0.052579,0.608741,-4.107191,-1.83652,0.120149,
	0.231733,0.017467,0.972623,-3.890388,-1.750102,0.017612,
	0.518386,-0.029316,0.854644,-3.778908,-0.541975,0.064258,
	0.875325,0.013439,0.483348,-3.818598,-0.52269,0.055572,
	0.891295,0.039311,0.451717,-3.900964,-0.780883,0.091579,
	0.518386,-0.029316,0.854644,-3.778908,-0.541975,0.064258,
	0.891295,0.039311,0.451717,-3.900964,-0.780883,0.091579,
	0.548941,0.015145,0.835724,-3.805841,-0.798961,0.099237,
	0.548941,0.015145,0.835724,-3.805841,-0.798961,0.099237,
	0.891295,0.039311,0.451717,-3.900964,-0.780883,0.091579,
	0.892259,-0.018571,0.451141,-3.949814,-0.963797,0.140806,
	0.548941,0.015145,0.835724,-3.805841,-0.798961,0.099237,
	0.892259,-0.018571,0.451141,-3.949814,-0.963797,0.140806,
	0.549332,-0.018885,0.835391,-3.843256,-0.981402,0.116282,
	0.549332,-0.018885,0.835391,-3.843256,-0.981402,0.116282,
	0.892259,-0.018571,0.451141,-3.949814,-0.963797,0.140806,
	0.843461,-0.305355,0.441963,-3.974499,-1.1696,0.164243,
	0.549332,-0.018885,0.835391,-3.843256,-0.981402,0.116282,
	0.843461,-0.305355,0.441963,-3.974499,-1.1696,0.164243,
	0.516335,-0.196022,0.833651,-3.884588,-1.261469,0.148322,
	0.516335,-0.196022,0.833651,-3.884588,-1.261469,0.148322,
	0.843461,-0.305355,0.441963,-3.974499,-1.1696,0.164243,
	0.589229,-0.690587,0.419402,-4.018866,-1.413191,0.154149,
	0.516335,-0.196022,0.833651,-3.884588,-1.261469,0.148322,
	0.589229,-0.690587,0.419402,-4.018866,-1.413191,0.154149,
	0.368421,-0.433142,0.82259,-3.914006,-1.486854,0.149147,
	0.368421,-0.433142,0.82259,-3.914006,-1.486854,0.149147,
	0.589229,-0.690587,0.419402,-4.018866,-1.413191,0.154149,
	0.389217,-0.829193,0.401185,-4.154334,-1.677827,0.165852,
	0.368421,-0.433142,0.82259,-3.914006,-1.486854,0.149147,
	0.389217,-0.829193,0.401185,-4.154334,-1.677827,0.165852,
	0.255239,-0.528232,0.80983,-4.015306,-1.659952,0.130331,
	0.255239,-0.528232,0.80983,-4.015306,-1.659952,0.130331,
	0.389217,-0.829193,0.401185,-4.154334,-1.677827,0.165852,
	0.981696,0.042552,-0.185638,-4.207566,-1.922824,0.155104,
	0.255239,-0.528232,0.80983,-4.015306,-1.659952,0.130331,
	0.981696,0.042552,-0.185638,-4.207566,-1.922824,0.155104,
	0.791625,0.052579,0.608741,-4.107191,-1.83652,0.120149,
	0.875325,0.013439,0.483348,-3.818598,-0.52269,0.055572,
	0.999006,0.044565,0.000415,-3.896204,-0.629183,0.077883,
	0.839295,0.00969,-0.54359,-3.978115,-0.82344,0.09928,
	0.875325,0.013439,0.483348,-3.818598,-0.52269,0.055572,
	0.839295,0.00969,-0.54359,-3.978115,-0.82344,0.09928,
	0.891295,0.039311,0.451717,-3.900964,-0.780883,0.091579,
	0.891295,0.039311,0.451717,-3.900964,-0.780883,0.091579,
	0.839295,0.00969,-0.54359,-3.978115,-0.82344,0.09928,
	0.874434,0.048946,-0.48267,-4.029726,-1.043238,0.136305,
	0.891295,0.039311,0.451717,-3.900964,-0.780883,0.091579,
	0.874434,0.048946,-0.48267,-4.029726,-1.043238,0.136305,
	0.892259,-0.018571,0.451141,-3.949814,-0.963797,0.140806,
	0.892259,-0.018571,0.451141,-3.949814,-0.963797,0.140806,
	0.874434,0.048946,-0.48267,-4.029726,-1.043238,0.136305,
	0.843461,-0.305355,0.441963,-3.974499,-1.1696,0.164243,
	0.843461,-0.305355,0.441963,-3.974499,-1.1696,0.164243,
	0.874434,0.048946,-0.48267,-4.029726,-1.043238,0.136305,
	0.432653,0.056559,-0.899785,-4.129295,-1.228786,0.120745,
	0.843461,-0.305355,0.441963,-3.974499,-1.1696,0.164243,
	0.432653,0.056559,-0.899785,-4.129295,-1.228786,0.120745,
	0.589229,-0.690587,0.419402,-4.018866,-1.413191,0.154149,
	0.589229,-0.690587,0.419402,-4.018866,-1.413191,0.154149,
	0.432653,0.056559,-0.899785,-4.129295,-1.228786,0.120745,
	0.517516,0.032105,-0.855071,-4.184154,-1.59808,0.151191,
	0.589229,-0.690587,0.419402,-4.018866,-1.413191,0.154149,
	0.517516,0.032105,-0.855071,-4.184154,-1.59808,0.151191,
	0.389217,-0.829193,0.401185,-4.154334,-1.677827,0.165852,
	0.389217,-0.829193,0.401185,-4.154334,-1.677827,0.165852,
	0.517516,0.032105,-0.855071,-4.184154,-1.59808,0.151191,
	0.002983,0.098874,-0.995096,-4.297769,-1.889903,0.177707,
	0.389217,-0.829193,0.401185,-4.154334,-1.677827,0.165852,
	0.002983,0.098874,-0.995096,-4.297769,-1.889903,0.177707,
	0.981696,0.042552,-0.185638,-4.207566,-1.922824,0.155104,
	0.999006,0.044565,0.000415,-3.896204,-0.629183,0.077883,
	0.001234,0.013557,-0.999907,-3.932489,-0.556566,0.037354,
	-0.369174,0.174156,-0.912897,-4.070739,-0.947648,0.110554,
	0.999006,0.044565,0.000415,-3.896204,-0.629183,0.077883,
	-0.369174,0.174156,-0.912897,-4.070739,-0.947648,0.110554,
	0.839295,0.00969,-0.54359,-3.978115,-0.82344,0.09928,
	0.839295,0.00969,-0.54359,-3.978115,-0.82344,0.09928,
	-0.369174,0.174156,-0.912897,-4.070739,-0.947648,0.110554,
	-0.516127,0.008586,-0.856469,-4.227645,-1.227895,0.069894,
	0.839295,0.00969,-0.54359,-3.978115,-0.82344,0.09928,
	-0.516127,0.008586,-0.856469,-4.227645,-1.227895,0.069894,
	0.874434,0.048946,-0.48267,-4.029726,-1.043238,0.136305,
	0.874434,0.048946,-0.48267,-4.029726,-1.043238,0.136305,
	-0.516127,0.008586,-0.856469,-4.227645,-1.227895,0.069894,
	-0.822516,0.195417,-0.534116,-4.229164,-1.473093,0.11156,
	0.874434,0.048946,-0.48267,-4.029726,-1.043238,0.136305,
	-0.822516,0.195417,-0.534116,-4.229164,-1.473093,0.11156,
	0.432653,0.056559,-0.899785,-4.129295,-1.228786,0.120745,
	0.432653,0.056559,-0.899785,-4.129295,-1.228786,0.120745,
	-0.822516,0.195417,-0.534116,-4.229164,-1.473093,0.11156,
	-0.874954,0.011842,-0.484061,-4.309744,-1.743848,0.150329,
	0.432653,0.056559,-0.899785,-4.129295,-1.228786,0.120745,
	-0.874954,0.011842,-0.484061,-4.309744,-1.743848,0.150329,
	0.517516,0.032105,-0.855071,-4.184154,-1.59808,0.151191,
	0.517516,0.032105,-0.855071,-4.184154,-1.59808,0.151191,
	-0.874954,0.011842,-0.484061,-4.309744,-1.743848,0.150329,
	0.924466,0.048977,0.378105,-4.405365,-1.921443,0.192978,
	0.517516,0.032105,-0.855071,-4.184154,-1.59808,0.151191,
	0.924466,0.048977,0.378105,-4.405365,-1.921443,0.192978,
	0.002983,0.098874,-0.995096,-4.297769,-1.889903,0.177707,
	0.001234,0.013557,-0.999907,-3.932489,-0.556566,0.037354,
	0.728068,-0.191899,-0.658097,-3.975337,-0.554961,-0.014407,
	0.313565,-0.18353,-0.931662,-4.112449,-0.875765,0.016326,
	0.001234,0.013557,-0.999907,-3.932489,-0.556566,0.037354,
	0.313565,-0.18353,-0.931662,-4.112449,-0.875765,0.016326,
	-0.369174,0.174156,-0.912897,-4.070739,-0.947648,0.110554,
	-0.369174,0.174156,-0.912897,-4.070739,-0.947648,0.110554,
	0.313565,-0.18353,-0.931662,-4.112449,-0.875765,0.016326,
	0.537835,-0.193789,-0.820475,-4.233834,-1.166542,0.022074,
	-0.369174,0.174156,-0.912897,-4.070739,-0.947648,0.110554,
	0.537835,-0.193789,-0.820475,-4.233834,-1.166542,0.022074,
	-0.516127,0.008586,-0.856469,-4.227645,-1.227895,0.069894,
	-0.516127,0.008586,-0.856469,-4.227645,-1.227895,0.069894,
	0.537835,-0.193789,-0.820475,-4.233834,-1.166542,0.022074,
	0.908243,-0.229695,0.349765,-4.333831,-1.548255,0.056938,
	-0.516127,0.008586,-0.856469,-4.227645,-1.227895,0.069894,
	0.908243,-0.229695,0.349765,-4.333831,-1.548255,0.056938,
	-0.822516,0.195417,-0.534116,-4.229164,-1.473093,0.11156,
	-0.822516,0.195417,-0.534116,-4.229164,-1.473093,0.11156,
	0.908243,-0.229695,0.349765,-4.333831,-1.548255,0.056938,
	0.701057,-0.21056,0.68131,-4.424122,-1.831742,0.130839,
	-0.822516,0.195417,-0.534116,-4.229164,-1.473093,0.11156,
	0.701057,-0.21056,0.68131,-4.424122,-1.831742,0.130839,
	-0.874954,0.011842,-0.484061,-4.309744,-1.743848,0.150329,
	-0.874954,0.011842,-0.484061,-4.309744,-1.743848,0.150329,
	0.701057,-0.21056,0.68131,-4.424122,-1.831742,0.130839,
	0.129519,-0.132707,0.982656,-4.445835,-2.015127,0.189702,
	-0.874954,0.011842,-0.484061,-4.309744,-1.743848,0.150329,
	0.129519,-0.132707,0.982656,-4.445835,-2.015127,0.189702,
	0.924466,0.048977,0.378105,-4.405365,-1.921443,0.192978,
	0.728068,-0.191899,-0.658097,-3.975337,-0.554961,-0.014407,
	-0.276108,-0.088023,0.957087,-3.921874,-0.538502,-0.145307,
	-0.409041,-0.077841,0.90919,-4.042715,-0.87671,-0.168968,
	0.728068,-0.191899,-0.658097,-3.975337,-0.554961,-0.014407,
	-0.409041,-0.077841,0.90919,-4.042715,-0.87671,-0.168968,
	0.313565,-0.18353,-0.931662,-4.112449,-0.875765,0.016326,
	0.313565,-0.18353,-0.931662,-4.112449,-0.875765,0.016326,
	-0.409041,-0.077841,0.90919,-4.042715,-0.87671,-0.168968,
	0.50178,0.000639,-0.864995,-4.216296,-1.160854,-0.104034,
	0.313565,-0.18353,-0.931662,-4.112449,-0.875765,0.016326,
	0.50178,0.000639,-0.864995,-4.216296,-1.160854,-0.104034,
	0.537835,-0.193789,-0.820475,-4.233834,-1.166542,0.022074,
	0.537835,-0.193789,-0.820475,-4.233834,-1.166542,0.022074,
	0.50178,0.000639,-0.864995,-4.216296,-1.160854,-0.104034,
	0.300485,0.019099,-0.953595,-4.252683,-1.437854,-0.14562,
	0.537835,-0.193789,-0.820475,-4.233834,-1.166542,0.022074,
	0.300485,0.019099,-0.953595,-4.252683,-1.437854,-0.14562,
	0.908243,-0.229695,0.349765,-4.333831,-1.548255,0.056938,
	0.908243,-0.229695,0.349765,-4.333831,-1.548255,0.056938,
	0.300485,0.019099,-0.953595,-4.252683,-1.437854,-0.14562,
	0.678632,-0.017853,-0.734261,-4.331331,-1.69259,-0.043593,
	0.908243,-0.229695,0.349765,-4.333831,-1.548255,0.056938,
	0.678632,-0.017853,-0.734261,-4.331331,-1.69259,-0.043593,
	0.701057,-0.21056,0.68131,-4.424122,-1.831742,0.130839,
	0.701057,-0.21056,0.68131,-4.424122,-1.831742,0.130839,
	0.678632,-0.017853,-0.734261,-4.331331,-1.69259,-0.043593,
	0.687126,-0.68509,0.241888,-4.387148,-1.967814,0.045602,
	0.701057,-0.21056,0.68131,-4.424122,-1.831742,0.130839,
	0.687126,-0.68509,0.241888,-4.387148,-1.967814,0.045602,
	0.129519,-0.132707,0.982656,-4.445835,-2.015127,0.189702,
	-0.276108,-0.088023,0.957087,-3.921874,-0.538502,-0.145307,
	0.260319,-0.908993,-0.325523,-3.910546,-0.601719,-0.163159,
	-0.148191,-0.901516,-0.40658,-3.988138,-0.962789,-0.223649,
	-0.276108,-0.088023,0.957087,-3.921874,-0.538502,-0.145307,
	-0.148191,-0.901516,-0.40658,-3.988138,-0.962789,-0.223649,
	-0.409041,-0.077841,0.90919,-4.042715,-0.87671,-0.168968,
	-0.409041,-0.077841,0.90919,-4.042715,-0.87671,-0.168968,
	-0.148191,-0.901516,-0.40658,-3.988138,-0.962789,-0.223649,
	-0.443612,-0.876487,-0.187028,-4.111927,-1.333141,-0.26716,
	-0.409041,-0.077841,0.90919,-4.042715,-0.87671,-0.168968,
	-0.443612,-0.876487,-0.187028,-4.111927,-1.333141,-0.26716,
	0.50178,0.000639,-0.864995,-4.216296,-1.160854,-0.104034,
	0.50178,0.000639,-0.864995,-4.216296,-1.160854,-0.104034,
	-0.443612,-0.876487,-0.187028,-4.111927,-1.333141,-0.26716,
	-0.508388,-0.837291,0.20121,-4.201904,-1.668554,-0.214859,
	0.50178,0.000639,-0.864995,-4.216296,-1.160854,-0.104034,
	-0.508388,-0.837291,0.20121,-4.201904,-1.668554,-0.214859,
	0.300485,0.019099,-0.953595,-4.252683,-1.437854,-0.14562,
	0.300485,0.019099,-0.953595,-4.252683,-1.437854,-0.14562,
	-0.508388,-0.837291,0.20121,-4.201904,-1.668554,-0.214859,
	-0.409829,-0.525605,0.745506,-4.273069,-1.798884,-0.099878,
	0.300485,0.019099,-0.953595,-4.252683,-1.437854,-0.14562,
	-0.409829,-0.525605,0.745506,-4.273069,-1.798884,-0.099878,
	0.678632,-0.017853,-0.734261,-4.331331,-1.69259,-0.043593,
	0.678632,-0.017853,-0.734261,-4.331331,-1.69259,-0.043593,
	-0.409829,-0.525605,0.745506,-4.273069,-1.798884,-0.099878,
	-0.227573,-0.361148,0.904313,-4.351543,-1.947675,0.02502,
	0.678632,-0.017853,-0.734261,-4.331331,-1.69259,-0.043593,
	-0.227573,-0.361148,0.904313,-4.351543,-1.947675,0.02502,
	0.687126,-0.68509,0.241888,-4.387148,-1.967814,0.045602,
	0.260319,-0.908993,-0.325523,-3.910546,-0.601719,-0.163159,
	0.10009,-0.380026,0.919545,-3.873622,-0.759035,-0.197169,
	0.547733,-0.470267,0.691981,-3.917882,-1.082831,-0.289171,
	0.260319,-0.908993,-0.325523,-3.910546,-0.601719,-0.163159,
	0.547733,-0.470267,0.691981,-3.917882,-1.082831,-0.289171,
	-0.148191,-0.901516,-0.40658,-3.988138,-0.962789,-0.223649,
	-0.148191,-0.901516,-0.40658,-3.988138,-0.962789,-0.223649,
	0.547733,-0.470267,0.691981,-3.917882,-1.082831,-0.289171,
	-0.071182,-0.950841,0.301389,-4.001496,-1.375703,-0.285641,
	-0.148191,-0.901516,-0.40658,-3.988138,-0.962789,-0.223649,
	-0.071182,-0.950841,0.301389,-4.001496,-1.375703,-0.285641,
	-0.443612,-0.876487,-0.187028,-4.111927,-1.333141,-0.26716,
	-0.443612,-0.876487,-0.187028,-4.111927,-1.333141,-0.26716,
	-0.071182,-0.950841,0.301389,-4.001496,-1.375703,-0.285641,
	0.216747,0.039317,0.975436,-4.073086,-1.649491,-0.238382,
	-0.443612,-0.876487,-0.187028,-4.111927,-1.333141,-0.26716,
	0.216747,0.039317,0.975436,-4.073086,-1.649491,-0.238382,
	-0.508388,-0.837291,0.20121,-4.201904,-1.668554,-0.214859,
	-0.508388,-0.837291,0.20121,-4.201904,-1.668554,-0.214859,
	0.216747,0.039317,0.975436,-4.073086,-1.649491,-0.238382,
	0.555948,0.246866,0.793712,-4.175757,-1.808223,-0.140659,
	-0.508388,-0.837291,0.20121,-4.201904,-1.668554,-0.214859,
	0.555948,0.246866,0.793712,-4.175757,-1.808223,-0.140659,
	-0.409829,-0.525605,0.745506,-4.273069,-1.798884,-0.099878,
	-0.409829,-0.525605,0.745506,-4.273069,-1.798884,-0.099878,
	0.555948,0.246866,0.793712,-4.175757,-1.808223,-0.140659,
	0.768311,0.202351,0.60725,-4.321269,-1.963488,0.025072,
	-0.409829,-0.525605,0.745506,-4.273069,-1.798884,-0.099878,
	0.768311,0.202351,0.60725,-4.321269,-1.963488,0.025072,
	-0.227573,-0.361148,0.904313,-4.351543,-1.947675,0.02502,
	0.10009,-0.380026,0.919545,-3.873622,-0.759035,-0.197169,
	0.833232,0.046885,0.550932,-3.742608,-0.729374,-0.149361,
	0.547733,-0.470267,0.691981,-3.917882,-1.082831,-0.289171,
	0.833232,0.046885,0.550932,-3.742608,-0.729374,-0.149361,
	0.587809,-0.328909,0.739121,-3.777709,-1.051411,-0.240495,
	0.547733,-0.470267,0.691981,-3.917882,-1.082831,-0.289171,
	0.547733,-0.470267,0.691981,-3.917882,-1.082831,-0.289171,
	0.587809,-0.328909,0.739121,-3.777709,-1.051411,-0.240495,
	-0.071182,-0.950841,0.301389,-4.001496,-1.375703,-0.285641,
	0.587809,-0.328909,0.739121,-3.777709,-1.051411,-0.240495,
	0.213242,-0.278117,0.936578,-3.82037,-1.239135,-0.269807,
	-0.071182,-0.950841,0.301389,-4.001496,-1.375703,-0.285641,
	0.213242,-0.278117,0.936578,-3.82037,-1.239135,-0.269807,
	0.794828,0.083383,0.601079,-4.000019,-1.567512,-0.27535,
	-0.071182,-0.950841,0.301389,-4.001496,-1.375703,-0.285641,
	-0.071182,-0.950841,0.301389,-4.001496,-1.375703,-0.285641,
	0.794828,0.083383,0.601079,-4.000019,-1.567512,-0.27535,
	0.216747,0.039317,0.975436,-4.073086,-1.649491,-0.238382,
	0.794828,0.083383,0.601079,-4.000019,-1.567512,-0.27535,
	0.873201,-0.045461,0.485235,-3.977657,-1.750845,-0.184909,
	0.216747,0.039317,0.975436,-4.073086,-1.649491,-0.238382,
	0.216747,0.039317,0.975436,-4.073086,-1.649491,-0.238382,
	0.873201,-0.045461,0.485235,-3.977657,-1.750845,-0.184909,
	0.555948,0.246866,0.793712,-4.175757,-1.808223,-0.140659,
	0.873201,-0.045461,0.485235,-3.977657,-1.750845,-0.184909,
	0.829377,-0.173626,0.531026,-4.075028,-1.904403,-0.041324,
	0.555948,0.246866,0.793712,-4.175757,-1.808223,-0.140659,
	0.555948,0.246866,0.793712,-4.175757,-1.808223,-0.140659,
	0.829377,-0.173626,0.531026,-4.075028,-1.904403,-0.041324,
	0.768311,0.202351,0.60725,-4.321269,-1.963488,0.025072,
	0.829377,-0.173626,0.531026,-4.075028,-1.904403,-0.041324,
	0.506864,-0.193038,0.840134,-4.192486,-1.953852,0.017313,
	0.768311,0.202351,0.60725,-4.321269,-1.963488,0.025072,
	0.274422,-0.24433,0.930051,-3.65524,-0.194907,0.019209,
	0.560378,0.257624,0.787151,-3.695565,-0.19362,0.051497,
	0.00197,-0.021649,0.999764,-3.740631,-0.558176,0.085478,
	0.274422,-0.24433,0.930051,-3.65524,-0.194907,0.019209,
	0.00197,-0.021649,0.999764,-3.740631,-0.558176,0.085478,
	-0.54555,-0.056478,0.836173,-3.67645,-0.551317,0.077574,
	0.546619,0.025488,0.836993,-3.805688,-0.190106,0.051472,
	0.728068,-0.191899,-0.658097,-3.975337,-0.554961,-0.014407,
	0.001234,0.013557,-0.999907,-3.932489,-0.556566,0.037354,
	0.546619,0.025488,0.836993,-3.805688,-0.190106,0.051472,
	0.001234,0.013557,-0.999907,-3.932489,-0.556566,0.037354,
	0.999006,0.044565,0.000415,-3.896204,-0.629183,0.077883,
	0.546619,0.025488,0.836993,-3.805688,-0.190106,0.051472,
	0.999006,0.044565,0.000415,-3.896204,-0.629183,0.077883,
	0.875325,0.013439,0.483348,-3.818598,-0.52269,0.055572,
	0.711192,0.127662,0.69131,-3.75063,-0.191863,0.063305,
	0.546619,0.025488,0.836993,-3.805688,-0.190106,0.051472,
	0.875325,0.013439,0.483348,-3.818598,-0.52269,0.055572,
	0.711192,0.127662,0.69131,-3.75063,-0.191863,0.063305,
	0.875325,0.013439,0.483348,-3.818598,-0.52269,0.055572,
	0.518386,-0.029316,0.854644,-3.778908,-0.541975,0.064258,
	0.560378,0.257624,0.787151,-3.695565,-0.19362,0.051497,
	0.518386,-0.029316,0.854644,-3.778908,-0.541975,0.064258,
	0.00197,-0.021649,0.999764,-3.740631,-0.558176,0.085478,
	0.238843,0.101951,0.965691,-3.84599,-0.18882,0.019164,
	0.166377,-0.157108,0.973466,-3.86074,-0.188349,-0.024962,
	0.728068,-0.191899,-0.658097,-3.975337,-0.554961,-0.014407,
	0.89264,0.349909,0.284178,-3.695452,-0.193624,-0.101369,
	0.833232,0.046885,0.550932,-3.742608,-0.729374,-0.149361,
	0.10009,-0.380026,0.919545,-3.873622,-0.759035,-0.197169,
	0.3526,0.621479,0.699598,-3.7505,-0.191867,-0.11323,
	0.89264,0.349909,0.284178,-3.695452,-0.193624,-0.101369,
	0.10009,-0.380026,0.919545,-3.873622,-0.759035,-0.197169,
	-0.281998,-0.030938,0.958916,-3.805575,-0.190109,-0.101447,
	0.3526,0.621479,0.699598,-3.7505,-0.191867,-0.11323,
	0.10009,-0.380026,0.919545,-3.873622,-0.759035,-0.197169,
	-0.281998,-0.030938,0.958916,-3.805575,-0.190109,-0.101447,
	0.10009,-0.380026,0.919545,-3.873622,-0.759035,-0.197169,
	0.260319,-0.908993,-0.325523,-3.910546,-0.601719,-0.163159,
	-0.281998,-0.030938,0.958916,-3.805575,-0.190109,-0.101447,
	0.260319,-0.908993,-0.325523,-3.910546,-0.601719,-0.163159,
	-0.276108,-0.088023,0.957087,-3.921874,-0.538502,-0.145307,
	0.077536,0.770695,0.632469,-3.845923,-0.188822,-0.06918,
	-0.281998,-0.030938,0.958916,-3.805575,-0.190109,-0.101447,
	-0.276108,-0.088023,0.957087,-3.921874,-0.538502,-0.145307,
	0.166377,-0.157108,0.973466,-3.86074,-0.188349,-0.024962,
	-0.276108,-0.088023,0.957087,-3.921874,-0.538502,-0.145307,
	0.728068,-0.191899,-0.658097,-3.975337,-0.554961,-0.014407,
	0.833232,0.046885,0.550932,-3.742608,-0.729374,-0.149361,
	-0.064166,-0.189382,0.979805,-3.655175,-0.194909,-0.069044,
	0.267717,-0.172975,0.947844,-3.640457,-0.195379,-0.024909,
	0.833232,0.046885,0.550932,-3.742608,-0.729374,-0.149361,
	0.89264,0.349909,0.284178,-3.695452,-0.193624,-0.101369,
	-0.064166,-0.189382,0.979805,-3.655175,-0.194909,-0.069044,
	0.274422,-0.24433,0.930051,-3.65524,-0.194907,0.019209,
	-0.54555,-0.056478,0.836173,-3.67645,-0.551317,0.077574,
	0.269003,0.86436,0.424875,-3.569386,-0.761644,-0.035893,
	0.269003,0.86436,0.424875,-3.569386,-0.761644,-0.035893,
	0.833232,0.046885,0.550932,-3.742608,-0.729374,-0.149361,
	0.267717,-0.172975,0.947844,-3.640457,-0.195379,-0.024909,
	-0.54555,-0.056478,0.836173,-3.67645,-0.551317,0.077574,
	-0.530021,0.13773,0.836724,-3.697889,-0.951955,0.098793,
	-0.429713,0.351913,0.831567,-3.666536,-1.140372,0.078261,
	0.213242,-0.278117,0.936578,-3.82037,-1.239135,-0.269807,
	0.587809,-0.328909,0.739121,-3.777709,-1.051411,-0.240495,
	0.000909,0.669011,0.743252,-3.581963,-1.413947,-0.104371,
	0.269003,0.86436,0.424875,-3.569386,-0.761644,-0.035893,
	-0.54555,-0.056478,0.836173,-3.67645,-0.551317,0.077574,
	-0.429713,0.351913,0.831567,-3.666536,-1.140372,0.078261,
	0.269003,0.86436,0.424875,-3.569386,-0.761644,-0.035893,
	-0.429713,0.351913,0.831567,-3.666536,-1.140372,0.078261,
	-0.24021,0.502412,0.830591,-3.639696,-1.242349,0.05719,
	0.269003,0.86436,0.424875,-3.569386,-0.761644,-0.035893,
	-0.24021,0.502412,0.830591,-3.639696,-1.242349,0.05719,
	0.000909,0.669011,0.743252,-3.581963,-1.413947,-0.104371,
	0.833232,0.046885,0.550932,-3.742608,-0.729374,-0.149361,
	0.269003,0.86436,0.424875,-3.569386,-0.761644,-0.035893,
	0.000909,0.669011,0.743252,-3.581963,-1.413947,-0.104371,
	0.587809,-0.328909,0.739121,-3.777709,-1.051411,-0.240495,
	0.833232,0.046885,0.550932,-3.742608,-0.729374,-0.149361,
	0.000909,0.669011,0.743252,-3.581963,-1.413947,-0.104371,
	0.873201,-0.045461,0.485235,-3.977657,-1.750845,-0.184909,
	0.231733,0.017467,0.972623,-3.890388,-1.750102,0.017612,
	0.829377,-0.173626,0.531026,-4.075028,-1.904403,-0.041324,
	0.873201,-0.045461,0.485235,-3.977657,-1.750845,-0.184909,
	0.794828,0.083383,0.601079,-4.000019,-1.567512,-0.27535,
	0.213242,-0.278117,0.936578,-3.82037,-1.239135,-0.269807,
	0.213242,-0.278117,0.936578,-3.82037,-1.239135,-0.269807,
	0.000909,0.669011,0.743252,-3.581963,-1.413947,-0.104371,
	-0.041225,-0.030655,0.99868,-3.683069,-1.591975,-0.115233,
	0.213242,-0.278117,0.936578,-3.82037,-1.239135,-0.269807,
	-0.041225,-0.030655,0.99868,-3.683069,-1.591975,-0.115233,
	0.002322,-0.058071,0.99831,-3.828485,-1.786559,-0.114095,
	0.213242,-0.278117,0.936578,-3.82037,-1.239135,-0.269807,
	0.002322,-0.058071,0.99831,-3.828485,-1.786559,-0.114095,
	0.231733,0.017467,0.972623,-3.890388,-1.750102,0.017612,
	0.873201,-0.045461,0.485235,-3.977657,-1.750845,-0.184909,
	0.213242,-0.278117,0.936578,-3.82037,-1.239135,-0.269807,
	0.231733,0.017467,0.972623,-3.890388,-1.750102,0.017612,
	0.231733,0.017467,0.972623,-3.890388,-1.750102,0.017612,
	0.791625,0.052579,0.608741,-4.107191,-1.83652,0.120149,
	0.829377,-0.173626,0.531026,-4.075028,-1.904403,-0.041324,
	0.791625,0.052579,0.608741,-4.107191,-1.83652,0.120149,
	0.981696,0.042552,-0.185638,-4.207566,-1.922824,0.155104,
	0.829377,-0.173626,0.531026,-4.075028,-1.904403,-0.041324,
	0.924466,0.048977,0.378105,-4.405365,-1.921443,0.192978,
	0.687126,-0.68509,0.241888,-4.387148,-1.967814,0.045602,
	0.002983,0.098874,-0.995096,-4.297769,-1.889903,0.177707,
	0.506864,-0.193038,0.840134,-4.192486,-1.953852,0.017313,
	0.829377,-0.173626,0.531026,-4.075028,-1.904403,-0.041324,
	0.981696,0.042552,-0.185638,-4.207566,-1.922824,0.155104,
	0.506864,-0.193038,0.840134,-4.192486,-1.953852,0.017313,
	0.981696,0.042552,-0.185638,-4.207566,-1.922824,0.155104,
	0.002983,0.098874,-0.995096,-4.297769,-1.889903,0.177707,
	0.768311,0.202351,0.60725,-4.321269,-1.963488,0.025072,
	0.506864,-0.193038,0.840134,-4.192486,-1.953852,0.017313,
	0.002983,0.098874,-0.995096,-4.297769,-1.889903,0.177707,
	-0.227573,-0.361148,0.904313,-4.351543,-1.947675,0.02502,
	0.768311,0.202351,0.60725,-4.321269,-1.963488,0.025072,
	0.002983,0.098874,-0.995096,-4.297769,-1.889903,0.177707,
	0.687126,-0.68509,0.241888,-4.387148,-1.967814,0.045602,
	-0.227573,-0.361148,0.904313,-4.351543,-1.947675,0.02502,
	0.002983,0.098874,-0.995096,-4.297769,-1.889903,0.177707,
	0.924466,0.048977,0.378105,-4.405365,-1.921443,0.192978,
	0.129519,-0.132707,0.982656,-4.445835,-2.015127,0.189702,
	0.687126,-0.68509,0.241888,-4.387148,-1.967814,0.045602,
	0.560378,0.257624,0.787151,-3.695565,-0.19362,0.051497,
	0.711192,0.127662,0.69131,-3.75063,-0.191863,0.063305,
	0.518386,-0.029316,0.854644,-3.778908,-0.541975,0.064258,
	0.546619,0.025488,0.836993,-3.805688,-0.190106,0.051472,
	0.238843,0.101951,0.965691,-3.84599,-0.18882,0.019164,
	0.728068,-0.191899,-0.658097,-3.975337,-0.554961,-0.014407,
	0.166377,-0.157108,0.973466,-3.86074,-0.188349,-0.024962,
	0.077536,0.770695,0.632469,-3.845923,-0.188822,-0.06918,
	-0.276108,-0.088023,0.957087,-3.921874,-0.538502,-0.145307,
	0.269003,0.86436,0.424875,-3.569386,-0.761644,-0.035893,
	0.267717,-0.172975,0.947844,-3.640457,-0.195379,-0.024909,
	0.274422,-0.24433,0.930051,-3.65524,-0.194907,0.019209
};
static const struct gllist frame={GL_N3F_V3F,GL_TRIANGLES,459,data,NULL};
const struct gllist *cow_tail=&frame;
